data {
	int<lower=0> N_obs;
	int<lower=1> I;
	int<lower=0> J;
	int<lower=0> K;
	int<lower=0> L;
	real<lower=-1,upper=1> amb[N_obs];
	real<lower=-1,upper=1> el[N_obs];
	int<lower=1,upper=3> stype[N_obs];
	int<lower=1,upper=8> roi[N_obs];
	real length[N_obs];
	vector<lower=0>[N_obs] dv;
	int<lower=1, upper=I> subject[N_obs];   //subject id
	int<lower=0> itemsoi[N_obs];   //SOI id
	int<lower=0> itemrrc[N_obs];   //RRC id
	int<lower=0> itemcdb[N_obs];   //CDB id
}

parameters	{
	real<lower=0> sigma;
	vector[22] alpha; // ROI-wise intercepts
	vector[67] beta; // Coefficients
	vector<lower=0>[90] sigma_u;	// subj sd
	vector<lower=0>[29] sigma_w;	// SOI sd
	vector<lower=0>[33] sigma_x;	// RRC sd
	vector<lower=0>[29] sigma_y;	// CDB sd
	cholesky_factor_corr[90] L_u;
	cholesky_factor_corr[29] L_w;
	cholesky_factor_corr[33] L_x;
	cholesky_factor_corr[29] L_y;
	matrix[90,I] z_u;
	matrix[29,J] z_w;
	matrix[33,K] z_x;
	matrix[29,L] z_y;
}

model {
	matrix[I,90] u;	// random intercept and slopes subj
	matrix[J,29] w;  // random intercept and slopes item
	matrix[K,33] x;  // random intercept and slopes item
	matrix[L,29] y;  // random intercept and slopes item
	u = (diag_pre_multiply(sigma_u,L_u) * z_u)';	// subj random effects
	w = (diag_pre_multiply(sigma_w,L_w) * z_w)';	// item random effects
	x = (diag_pre_multiply(sigma_x,L_x) * z_x)';	// item random effects
	y = (diag_pre_multiply(sigma_y,L_y) * z_y)';	// item random effects
	
	alpha ~ cauchy(0,2.5);
	sigma ~ cauchy(0,2.5);
	beta ~ cauchy(0,2.5);
	sigma_u ~ cauchy(0,2.5);
	sigma_w ~ cauchy(0,2.5);
	sigma_x ~ cauchy(0,2.5);
	sigma_y ~ cauchy(0,2.5);
	L_u ~ lkj_corr_cholesky(2.0);
	L_w ~ lkj_corr_cholesky(2.0);
	L_x ~ lkj_corr_cholesky(2.0);
	L_y ~ lkj_corr_cholesky(2.0);
	to_vector(z_u) ~ normal(0,1);
	to_vector(z_w) ~ normal(0,1);
	to_vector(z_x) ~ normal(0,1);
	to_vector(z_y) ~ normal(0,1);
	
	for (n in 1:N_obs) {
	real mu;
	
	if (stype[n] == 1) {
	    // SOI NP1/1
		if (roi[n] == 1) {
			mu = alpha[1]+u[subject[n],1]+w[itemsoi[n],1]+
			u[subject[n],3]+w[itemsoi[n],23]+
			(beta[2]+u[subject[n],4]+w[itemsoi[n],2])*el[n]+
			(beta[3]+u[subject[n],5]+w[itemsoi[n],3])*amb[n]+
			(beta[4]+u[subject[n],6]+w[itemsoi[n],4])*el[n]*amb[n]+
			(beta[1]+u[subject[n],2])*length[n];
		// SOI NP1/2
		} else if (roi[n] == 2) {
			mu = alpha[2]+u[subject[n],1]+w[itemsoi[n],1]+
			u[subject[n],7]+w[itemsoi[n],24]+
			(beta[5]+u[subject[n],8]+w[itemsoi[n],5])*el[n]+
			(beta[6]+u[subject[n],9]+w[itemsoi[n],6])*amb[n]+
			(beta[7]+u[subject[n],10]+w[itemsoi[n],7])*el[n]*amb[n]+
			(beta[1]+u[subject[n],2])*length[n];
		// SOI AUX
		} else if (roi[n] == 3) {
			mu = alpha[3]+u[subject[n],1]+w[itemsoi[n],1]+
			u[subject[n],11]+w[itemsoi[n],25]+
			(beta[8]+u[subject[n],12]+w[itemsoi[n],8])*el[n]+
			(beta[9]+u[subject[n],13]+w[itemsoi[n],9])*amb[n]+
			(beta[10]+u[subject[n],14]+w[itemsoi[n],10])*el[n]*amb[n]+
			(beta[1]+u[subject[n],2])*length[n];
		// SOI NP2/1
		} else if (roi[n] == 4) {
			mu = alpha[4]+u[subject[n],1]+w[itemsoi[n],1]+
			u[subject[n],15]+w[itemsoi[n],26]+
			(beta[11]+u[subject[n],16]+w[itemsoi[n],11])*el[n]+
			(beta[12]+u[subject[n],17]+w[itemsoi[n],12])*amb[n]+
			(beta[13]+u[subject[n],18]+w[itemsoi[n],13])*el[n]*amb[n]+
			(beta[1]+u[subject[n],2])*length[n];
		// SOI NP2/2
		} else if (roi[n] == 5) {
			mu = alpha[5]+u[subject[n],1]+w[itemsoi[n],1]+
			u[subject[n],19]+w[itemsoi[n],27]+
			(beta[14]+u[subject[n],20]+w[itemsoi[n],14])*el[n]+
			(beta[15]+u[subject[n],21]+w[itemsoi[n],15])*amb[n]+
			(beta[16]+u[subject[n],22]+w[itemsoi[n],16])*el[n]*amb[n]+
			(beta[1]+u[subject[n],2])*length[n];
		// SOI SLUICE
		} else if (roi[n] == 6) {
			mu = alpha[6]+u[subject[n],1]+w[itemsoi[n],1]+
			u[subject[n],23]+w[itemsoi[n],28]+
			(beta[17]+u[subject[n],24]+w[itemsoi[n],17])*el[n]+
			(beta[18]+u[subject[n],25]+w[itemsoi[n],18])*amb[n]+
			(beta[19]+u[subject[n],26]+w[itemsoi[n],19])*el[n]*amb[n]+
			(beta[1]+u[subject[n],2])*length[n];
		// SOI SPILLOVER
		} else if (roi[n] == 7) { 
			mu = alpha[7]+u[subject[n],1]+w[itemsoi[n],1]+
			u[subject[n],27]+w[itemsoi[n],29]+
			(beta[20]+u[subject[n],28]+w[itemsoi[n],20])*el[n]+
			(beta[21]+u[subject[n],29]+w[itemsoi[n],21])*amb[n]+
			(beta[22]+u[subject[n],30]+w[itemsoi[n],22])*el[n]*amb[n]+
			(beta[1]+u[subject[n],2])*length[n];
		}
		
	} else if (stype[n] == 2) {
		// RRC NP1
		if (roi[n] == 1) {
			mu = alpha[8]+u[subject[n],1]+x[itemrrc[n],1]+
			u[subject[n],31]+x[itemrrc[n],26]+
			(beta[23]+u[subject[n],32]+x[itemrrc[n],2])*el[n]+
			(beta[24]+u[subject[n],33]+x[itemrrc[n],3])*amb[n]+
			(beta[25]+u[subject[n],34]+x[itemrrc[n],4])*el[n]*amb[n]+
			(beta[1]+u[subject[n],2])*length[n];
		// RRC PART
		} else if (roi[n] == 2) {
			mu = alpha[9]+u[subject[n],1]+x[itemrrc[n],1]+
			u[subject[n],35]+x[itemrrc[n],27]+
			(beta[26]+u[subject[n],36]+x[itemrrc[n],5])*el[n]+
			(beta[27]+u[subject[n],37]+x[itemrrc[n],6])*amb[n]+
			(beta[28]+u[subject[n],38]+x[itemrrc[n],7])*el[n]*amb[n]+
			(beta[1]+u[subject[n],2])*length[n];
		// RRC PP
		} else if (roi[n] == 3) {
			mu = alpha[10]+u[subject[n],1]+x[itemrrc[n],1]+
			u[subject[n],39]+x[itemrrc[n],28]+
			(beta[29]+u[subject[n],40]+x[itemrrc[n],8])*el[n]+
			(beta[30]+u[subject[n],41]+x[itemrrc[n],9])*amb[n]+
			(beta[31]+u[subject[n],42]+x[itemrrc[n],10])*el[n]*amb[n]+
			(beta[1]+u[subject[n],2])*length[n];
		// RRC DIS
		} else if (roi[n] == 4) {
			mu = alpha[11]+u[subject[n],1]+x[itemrrc[n],1]+
			u[subject[n],43]+x[itemrrc[n],29]+
			(beta[32]+u[subject[n],44]+x[itemrrc[n],11])*el[n]+
			(beta[33]+u[subject[n],45]+x[itemrrc[n],12])*amb[n]+
			(beta[34]+u[subject[n],46]+x[itemrrc[n],13])*el[n]*amb[n]+
			(beta[1]+u[subject[n],2])*length[n];
		// RRC POST-DIS
		} else if (roi[n] == 5) {
			mu = alpha[12]+u[subject[n],1]+x[itemrrc[n],1]+
			u[subject[n],47]+x[itemrrc[n],30]+
			(beta[35]+u[subject[n],48]+x[itemrrc[n],14])*el[n]+
			(beta[36]+u[subject[n],49]+x[itemrrc[n],15])*amb[n]+
			(beta[37]+u[subject[n],50]+x[itemrrc[n],16])*el[n]*amb[n]+
			(beta[1]+u[subject[n],2])*length[n];
		// RRC PRE-SLUICE
		} else if (roi[n] == 6) {
			mu = alpha[13]+u[subject[n],1]+x[itemrrc[n],1]+
			u[subject[n],51]+x[itemrrc[n],31]+
			(beta[38]+u[subject[n],52]+x[itemrrc[n],17])*el[n]+
			(beta[39]+u[subject[n],53]+x[itemrrc[n],18])*amb[n]+
			(beta[40]+u[subject[n],54]+x[itemrrc[n],19])*el[n]*amb[n]+
			(beta[1]+u[subject[n],2])*length[n];
		// RRC SLUICE
		} else if (roi[n] == 7) {
			mu = alpha[14]+u[subject[n],1]+x[itemrrc[n],1]+
			u[subject[n],55]+x[itemrrc[n],32]+
			(beta[41]+u[subject[n],56]+x[itemrrc[n],20])*el[n]+
			(beta[42]+u[subject[n],57]+x[itemrrc[n],21])*amb[n]+
			(beta[43]+u[subject[n],58]+x[itemrrc[n],22])*el[n]*amb[n]+
			(beta[1]+u[subject[n],2])*length[n];
		// RRC SPILLOVER
		} else if (roi[n] == 8) { 
			mu = alpha[15]+u[subject[n],1]+x[itemrrc[n],1]+
			u[subject[n],59]+x[itemrrc[n],33]+
			(beta[44]+u[subject[n],60]+x[itemrrc[n],23])*el[n]+
			(beta[45]+u[subject[n],61]+x[itemrrc[n],24])*amb[n]+
			(beta[46]+u[subject[n],62]+x[itemrrc[n],25])*el[n]*amb[n]+
			(beta[1]+u[subject[n],2])*length[n];
		}
	
	} else if (stype[n] == 3) {
		// TLA NP1
		if (roi[n] == 1) {
			mu = alpha[16]+u[subject[n],1]+y[itemcdb[n],1]+
			u[subject[n],63]+y[itemcdb[n],23]+
			(beta[47]+u[subject[n],64]+y[itemcdb[n],2])*el[n]+
			(beta[48]+u[subject[n],65]+y[itemcdb[n],3])*amb[n]+
			(beta[49]+u[subject[n],66]+y[itemcdb[n],4])*el[n]*amb[n]+
			(beta[1]+u[subject[n],2])*length[n];
		// TLA ADJ
		} else if (roi[n] == 2) {
			mu = alpha[17]+u[subject[n],1]+y[itemcdb[n],1]+
			u[subject[n],67]+y[itemcdb[n],24]+
			(beta[50]+u[subject[n],68]+y[itemcdb[n],5])*el[n]+
			(beta[51]+u[subject[n],69]+y[itemcdb[n],6])*amb[n]+
			(beta[52]+u[subject[n],70]+y[itemcdb[n],7])*el[n]*amb[n]+
			(beta[1]+u[subject[n],2])*length[n];
		// TLA VERB+PRONOUN
		} else if (roi[n] == 3) {
			mu = alpha[18]+u[subject[n],1]+y[itemcdb[n],1]+
			u[subject[n],71]+y[itemcdb[n],25]+
			(beta[53]+u[subject[n],72]+y[itemcdb[n],8])*el[n]+
			(beta[54]+u[subject[n],73]+y[itemcdb[n],9])*amb[n]+
			(beta[55]+u[subject[n],74]+y[itemcdb[n],10])*el[n]*amb[n]+
			(beta[1]+u[subject[n],2])*length[n];
		// TLA POST-VERB
		} else if (roi[n] == 4) {
			mu = alpha[19]+u[subject[n],1]+y[itemcdb[n],1]+
			u[subject[n],75]+y[itemcdb[n],26]+
			(beta[56]+u[subject[n],76]+y[itemcdb[n],11])*el[n]+
			(beta[57]+u[subject[n],77]+y[itemcdb[n],12])*amb[n]+
			(beta[58]+u[subject[n],78]+y[itemcdb[n],13])*el[n]*amb[n]+
			(beta[1]+u[subject[n],2])*length[n];
		// TLA PRE-SLUICE
		} else if (roi[n] == 5) {
			mu = alpha[20]+u[subject[n],1]+y[itemcdb[n],1]+
			u[subject[n],79]+y[itemcdb[n],27]+
			(beta[59]+u[subject[n],80]+y[itemcdb[n],14])*el[n]+
			(beta[60]+u[subject[n],81]+y[itemcdb[n],15])*amb[n]+
			(beta[61]+u[subject[n],82]+y[itemcdb[n],16])*el[n]*amb[n]+
			(beta[1]+u[subject[n],2])*length[n];
		// TLA SLUICE
		} else if (roi[n] == 6) {
			mu = alpha[21]+u[subject[n],1]+y[itemcdb[n],1]+
			u[subject[n],83]+y[itemcdb[n],28]+
			(beta[62]+u[subject[n],84]+y[itemcdb[n],17])*el[n]+
			(beta[63]+u[subject[n],85]+y[itemcdb[n],18])*amb[n]+
			(beta[64]+u[subject[n],86]+y[itemcdb[n],19])*el[n]*amb[n]+
			(beta[1]+u[subject[n],2])*length[n];
		// TLA SPILLOVER
		} else if (roi[n] == 7) { 
			mu = alpha[22]+u[subject[n],1]+y[itemcdb[n],1]+
			u[subject[n],87]+y[itemcdb[n],29]+
			(beta[65]+u[subject[n],88]+y[itemcdb[n],20])*el[n]+
			(beta[66]+u[subject[n],89]+y[itemcdb[n],21])*amb[n]+
			(beta[67]+u[subject[n],90]+y[itemcdb[n],22])*el[n]*amb[n]+
			(beta[1]+u[subject[n],2])*length[n];
		}
	
	}
	
	dv[n] ~ lognormal(mu,sigma);
	
	}
}
