data {
	int<lower=0> N_obs;
	int<lower=1> I;
	int<lower=0> J;
	int<lower=0> K;
	int<lower=0> L;
	real<lower=-1,upper=1> amb[N_obs];
	real<lower=-1,upper=1> el[N_obs];
	int<lower=1,upper=3> stype[N_obs];
	real<lower=0> rt[N_obs];
	int<lower=1, upper=I> subject[N_obs];   //subject id
	int<lower=0> itemsoi[N_obs];   //SOI id
	int<lower=0> itemrrc[N_obs];   //RRC id
	int<lower=0> itemcdb[N_obs];   //CDB id
}

parameters	{
	real<lower=0> sigma;
	vector[3] alpha; // Intercepts by sentence type
	vector[9] beta; // Coefficients
	vector<lower=0>[13] sigma_u;	// subj sd
	vector<lower=0>[4] sigma_w;	// SOI sd
	vector<lower=0>[4] sigma_x;	// RRC sd
	vector<lower=0>[4] sigma_y;	// CDB sd
	cholesky_factor_corr[13] L_u;
	cholesky_factor_corr[4] L_w;
	cholesky_factor_corr[4] L_x;
	cholesky_factor_corr[4] L_y;
	matrix[13,I] z_u;
	matrix[4,J] z_w;
	matrix[4,K] z_x;
	matrix[4,L] z_y;
}

model {
	matrix[I,13] u;	// random intercept and slopes subj
	matrix[J,4] w;  // random intercept and slopes item
	matrix[K,4] x;  // random intercept and slopes item
	matrix[L,4] y;  // random intercept and slopes item
	u = (diag_pre_multiply(sigma_u,L_u) * z_u)';	// subj random effects
	w = (diag_pre_multiply(sigma_w,L_w) * z_w)';	// item random effects
	x = (diag_pre_multiply(sigma_x,L_x) * z_x)';	// item random effects
	y = (diag_pre_multiply(sigma_y,L_y) * z_y)';	// item random effects
	
	alpha ~ cauchy(0,2.5);
	beta ~ cauchy(0,2.5);
	sigma ~ cauchy(0,2.5);
	sigma_u ~ cauchy(0,2.5);
	sigma_w ~ cauchy(0,2.5);
	sigma_x ~ cauchy(0,2.5);
	sigma_y ~ cauchy(0,2.5);
	L_u ~ lkj_corr_cholesky(2.0);
	L_w ~ lkj_corr_cholesky(2.0);
	L_x ~ lkj_corr_cholesky(2.0);
	L_y ~ lkj_corr_cholesky(2.0);
	to_vector(z_u) ~ normal(0,1);
	to_vector(z_w) ~ normal(0,1);
	to_vector(z_x) ~ normal(0,1);
	to_vector(z_y) ~ normal(0,1);
	
	for (n in 1:N_obs) {
	real mu;
	
	if (stype[n] == 1) {
	    
		mu = alpha[1]+u[subject[n],1]+w[itemsoi[n],1]+u[subject[n],11]+
		(beta[1]+u[subject[n],2]+w[itemsoi[n],2])*el[n]+
		(beta[2]+u[subject[n],3]+w[itemsoi[n],3])*amb[n]+
		(beta[3]+u[subject[n],4]+w[itemsoi[n],4])*el[n]*amb[n];
		
	} else if (stype[n] == 2) {
	
		mu = alpha[2]+u[subject[n],1]+x[itemrrc[n],1]+u[subject[n],12]+
		(beta[4]+u[subject[n],5]+x[itemrrc[n],2])*el[n]+
		(beta[5]+u[subject[n],6]+x[itemrrc[n],3])*amb[n]+
		(beta[6]+u[subject[n],7]+x[itemrrc[n],4])*el[n]*amb[n];
	
	} else if (stype[n] == 3) {
	
		mu = alpha[3]+u[subject[n],1]+y[itemcdb[n],1]+u[subject[n],13]+
		(beta[7]+u[subject[n],8]+y[itemcdb[n],2])*el[n]+
		(beta[8]+u[subject[n],9]+y[itemcdb[n],3])*amb[n]+
		(beta[9]+u[subject[n],10]+y[itemcdb[n],4])*el[n]*amb[n];
	
	}
	
	rt[n] ~ lognormal(mu,sigma);
	
	}
}
