data {
	int<lower=0> N_obs;
	int<lower=1> I;
	int<lower=1> J;
	real<lower=-1,upper=1> order[N_obs];
	real<lower=-1,upper=1> gender[N_obs];
	int<lower=1,upper=8> roi[N_obs];
	real length[N_obs];
	vector<lower=0>[N_obs] dv;
	int<lower=1, upper=I> subject[N_obs];   //subject id
	int<lower=1, upper=J> item[N_obs];   //item id
}

parameters	{
	real<lower=0> sigma;
	vector[8] alpha; // ROI-wise intercepts
	vector[25] beta; // Coefficients
	vector<lower=0>[34] sigma_u;	// subj sd
	vector<lower=0>[33] sigma_w;	// item sd
	cholesky_factor_corr[34] L_u;
	cholesky_factor_corr[33] L_w;
	matrix[34,I] z_u;
	matrix[33,J] z_w;
}

model {
	matrix[I,34] u;	// random intercept and slopes subj
	matrix[J,33] w;  // random intercept and slopes item
	u = (diag_pre_multiply(sigma_u,L_u) * z_u)';	// subj random effects
	w = (diag_pre_multiply(sigma_w,L_w) * z_w)';	// item random effects
	
	alpha ~ cauchy(0,2.5);
	sigma ~ cauchy(0,2.5);
	beta ~ cauchy(0,2.5);
	sigma_u ~ cauchy(0,2.5);
	sigma_w ~ cauchy(0,2.5);
	L_u ~ lkj_corr_cholesky(2.0);
	L_w ~ lkj_corr_cholesky(2.0);
	to_vector(z_u) ~ normal(0,1);
	to_vector(z_w) ~ normal(0,1);
	
	for (n in 1:N_obs) {
	real mu;
		// NP1
		if (roi[n] == 1) {
			mu = alpha[1]+u[subject[n],1]+w[item[n],1]+
			u[subject[n],3]+w[item[n],26]+
			(beta[2]+u[subject[n],4]+w[item[n],2])*gender[n]+
			(beta[3]+u[subject[n],5]+w[item[n],3])*order[n]+
			(beta[4]+u[subject[n],6]+w[item[n],4])*gender[n]*order[n]+
			(beta[1]+u[subject[n],2])*length[n];
		// AUX
		} else if (roi[n] == 2) {
			mu = alpha[2]+u[subject[n],1]+w[item[n],1]+
			u[subject[n],7]+w[item[n],27]+
			(beta[5]+u[subject[n],8]+w[item[n],5])*gender[n]+
			(beta[6]+u[subject[n],9]+w[item[n],6])*order[n]+
			(beta[7]+u[subject[n],10]+w[item[n],7])*gender[n]*order[n]+
			(beta[1]+u[subject[n],2])*length[n];
		// NP2
		} else if (roi[n] == 3) {
			mu = alpha[3]+u[subject[n],1]+w[item[n],1]+
			u[subject[n],11]+w[item[n],28]+
			(beta[8]+u[subject[n],12]+w[item[n],8])*gender[n]+
			(beta[9]+u[subject[n],13]+w[item[n],9])*order[n]+
			(beta[10]+u[subject[n],14]+w[item[n],10])*gender[n]*order[n]+
			(beta[1]+u[subject[n],2])*length[n];
		// ADJ
		} else if (roi[n] == 4) {
			mu = alpha[4]+u[subject[n],1]+w[item[n],1]+
			u[subject[n],15]+w[item[n],29]+
			(beta[11]+u[subject[n],16]+w[item[n],11])*gender[n]+
			(beta[12]+u[subject[n],17]+w[item[n],12])*order[n]+
			(beta[13]+u[subject[n],18]+w[item[n],13])*gender[n]*order[n]+
			(beta[1]+u[subject[n],2])*length[n];
		// VERB
		} else if (roi[n] == 5) {
			mu = alpha[5]+u[subject[n],1]+w[item[n],1]+
			u[subject[n],19]+w[item[n],30]+
			(beta[14]+u[subject[n],20]+w[item[n],14])*gender[n]+
			(beta[15]+u[subject[n],21]+w[item[n],15])*order[n]+
			(beta[16]+u[subject[n],22]+w[item[n],16])*gender[n]*order[n]+
			(beta[1]+u[subject[n],2])*length[n];
		// PRE-CRIT
		} else if (roi[n] == 6) {
			mu = alpha[6]+u[subject[n],1]+w[item[n],1]+
			u[subject[n],23]+w[item[n],31]+
			(beta[17]+u[subject[n],24]+w[item[n],17])*gender[n]+
			(beta[18]+u[subject[n],25]+w[item[n],18])*order[n]+
			(beta[19]+u[subject[n],26]+w[item[n],19])*gender[n]*order[n]+
			(beta[1]+u[subject[n],2])*length[n];
		// CRIT
		} else if (roi[n] == 7) { 
			mu = alpha[7]+u[subject[n],1]+w[item[n],1]+
			u[subject[n],27]+w[item[n],32]+
			(beta[20]+u[subject[n],28]+w[item[n],20])*gender[n]+
			(beta[21]+u[subject[n],29]+w[item[n],21])*order[n]+
			(beta[22]+u[subject[n],30]+w[item[n],22])*gender[n]*order[n]+
			(beta[1]+u[subject[n],2])*length[n];
		// SPILLOVER	
		} else if (roi[n] == 8) { 
			mu = alpha[8]+u[subject[n],1]+w[item[n],1]+
			u[subject[n],31]+w[item[n],33]+
			(beta[23]+u[subject[n],32]+w[item[n],23])*gender[n]+
			(beta[24]+u[subject[n],33]+w[item[n],24])*order[n]+
			(beta[25]+u[subject[n],34]+w[item[n],25])*gender[n]*order[n]+
			(beta[1]+u[subject[n],2])*length[n];
		}
	
	dv[n] ~ lognormal(mu,sigma);
	
	}
}
