data {
	int<lower=0> N_obs;
	int<lower=1> I;
	int<lower=0> J;
	int<lower=0> K;
	int<lower=0> L;
	int<lower=2> G;
	real<lower=-1,upper=1> cond[N_obs];
	int<lower=1,upper=3> stype[N_obs];
	int<lower=1,upper=G> rating[N_obs];
	int<lower=1, upper=I> subject[N_obs];   //subject id
	int<lower=0> itemsoi[N_obs];   //SOI id
	int<lower=0> itemrrc[N_obs];   //RRC id
	int<lower=0> itemcdb[N_obs];   //CDB id
}

parameters	{
	vector[3] alpha; // ROI-wise intercepts
	vector[3] beta; // Coefficients
	vector<lower=0>[15] sigma_u;	// subj sd
	vector<lower=0>[2] sigma_w;	// SOI sd
	vector<lower=0>[2] sigma_x;	// RRC sd
	vector<lower=0>[2] sigma_y;	// CDB sd
	cholesky_factor_corr[15] L_u;
	cholesky_factor_corr[2] L_w;
	cholesky_factor_corr[2] L_x;
	cholesky_factor_corr[2] L_y;
	matrix[15,I] z_u;
	matrix[2,J] z_w;
	matrix[2,K] z_x;
	matrix[2,L] z_y;
	ordered[G-1] c; // Shared cutpoints across sentence types
}

model {
	matrix[I,15] u;  // random intercept and slopes item
	matrix[J,2] w;  // random intercept and slopes item
	matrix[K,2] x;  // random intercept and slopes item
	matrix[L,2] y;  // random intercept and slopes item

	u = (diag_pre_multiply(sigma_u,L_u) * z_u)';
	w = (diag_pre_multiply(sigma_w,L_w) * z_w)';	// item random effects
	x = (diag_pre_multiply(sigma_x,L_x) * z_x)';	// item random effects
	y = (diag_pre_multiply(sigma_y,L_y) * z_y)';	// item random effects
	
	c ~ cauchy(0,2.5);
	alpha ~ cauchy(0,2.5);
	beta ~ cauchy(0,2.5);
	sigma_u ~ cauchy(0,2.5);
	sigma_w ~ cauchy(0,2.5);
	sigma_x ~ cauchy(0,2.5);
	sigma_y ~ cauchy(0,2.5);
	L_u ~ lkj_corr_cholesky(2.0);
	L_w ~ lkj_corr_cholesky(2.0);
	L_x ~ lkj_corr_cholesky(2.0);
	L_y ~ lkj_corr_cholesky(2.0);
	to_vector(z_u) ~ normal(0,1);
	to_vector(z_w) ~ normal(0,1);
	to_vector(z_x) ~ normal(0,1);
	to_vector(z_y) ~ normal(0,1);
	
	for (n in 1:N_obs) {
	real eta;
	
	if (stype[n] == 1) {
	
		eta = alpha[1]+u[subject[n],1]+u[subject[n],5]+x[itemrrc[n],1]+(cond[n]+u[subject[n],2]+x[itemrrc[n],2])*beta[1];
		
	} else if (stype[n] == 2) {
	
		eta = alpha[2]+u[subject[n],1]+u[subject[n],6]+y[itemcdb[n],1]+(cond[n]+u[subject[n],3]+y[itemcdb[n],2])*beta[2];
	
	} else if (stype[n] == 3) {
	
		eta = alpha[3]+u[subject[n],1]+u[subject[n],7]+w[itemsoi[n],1]+(cond[n]+u[subject[n],4]+w[itemsoi[n],2])*beta[3];
	
	}
	
	rating[n] ~ ordered_logistic(eta, c);

	}
}

